==> veriloggen-1.8.6.tar.gz: veriloggen-1.8.6/tests/extension/types_/rom_/sync_enable/types_rom_sync_enable.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os
import math

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.rom as rom


def mkMain(n=128, datawidth=32, numports=2):
    m = Module('main')

    clk = m.Input('CLK')
    rst = m.Input('RST')

    width = 4
    addr = m.Reg('addr', width, initval=0)
    values = [ i * i for i in range(2 ** width) ]
    enable = m.Reg('enable', initval=0)

    myrom = rom.SyncROM(m, 'myrom', clk, addr, values, datawidth=8, enable=enable)

    seq = Seq(m, 'seq', clk, rst)

    seq(
        enable(Not(enable)),
    )
    seq.If(enable)(
        addr.inc(),
        Display('addr=%d rdata=%d', addr, myrom.rdata)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    main = mkMain()

    # copy paras and ports
    params = m.copy_params(main)
    ports = m.copy_sim_ports(main)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(main, 'uut',
                     params=m.connect_params(main),
                     ports=m.connect_ports(main))

    simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000 * 100),
        Systask('finish'),
    )

    return m

if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()

==> veriloggen-2.0.0.tar.gz: veriloggen-2.0.0/tests/extension/types_/rom_/sync_enable/types_rom_sync_enable.py <==
from __future__ import absolute_import
from __future__ import print_function
import sys
import os
import math

# the next line can be removed after installation
sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.dirname(
    os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))))))

from veriloggen import *
import veriloggen.types.rom as rom


def mkMain(n=128, datawidth=32, numports=2):
    m = Module('main')

    clk = m.Input('CLK')
    rst = m.Input('RST')

    width = 4
    addr = m.Reg('addr', width, initval=0)
    values = [i * i for i in range(2 ** width)]
    enable = m.Reg('enable', initval=0)

    myrom = rom.SyncROM(m, 'myrom', clk, addr, values, datawidth=8, enable=enable)

    seq = Seq(m, 'seq', clk, rst)

    seq(
        enable(Not(enable)),
    )
    seq.If(enable)(
        addr.inc(),
        Display('addr=%d rdata=%d', addr, myrom.rdata)
    )

    return m


def mkTest():
    m = Module('test')

    # target instance
    main = mkMain()

    # copy paras and ports
    params = m.copy_params(main)
    ports = m.copy_sim_ports(main)

    clk = ports['CLK']
    rst = ports['RST']

    uut = m.Instance(main, 'uut',
                     params=m.connect_params(main),
                     ports=m.connect_ports(main))

    # simulation.setup_waveform(m, uut, m.get_vars())
    simulation.setup_clock(m, clk, hperiod=5)
    init = simulation.setup_reset(m, rst, m.make_reset(), period=100)

    init.add(
        Delay(1000 * 100),
        Systask('finish'),
    )

    return m


if __name__ == '__main__':
    test = mkTest()
    verilog = test.to_verilog('tmp.v')
    print(verilog)

    sim = simulation.Simulator(test)
    rslt = sim.run()
    print(rslt)

    # sim.view_waveform()
